@@ -23,6 +23,7 @@
 
 #include <gstdio.h>
 #include <errno.h>
+#include <locale.h>
 
 static gboolean
 is_valid_module_name (const gchar *basename)
@@ -118,6 +119,7 @@ query_dir (const char *dirname)
         g_printerr ("Unable to unlink %s: %s\n", cachename, g_strerror (errno));
     }
 
+  g_free (cachename);
   g_string_free (data, TRUE);
 }
 
@@ -134,6 +136,8 @@ main (gint   argc,
       return 1;
     }
 
+  setlocale (LC_ALL, "");
+
   /* Be defensive and ensure we're linked to GObject */
   g_type_ensure (G_TYPE_OBJECT);
 
