@@ -254,6 +254,12 @@ g_io_error_from_errno (gint err_no)
       break;
 #endif
 
+#ifdef EMSGSIZE
+    case EMSGSIZE:
+      return G_IO_ERROR_MESSAGE_TOO_LARGE;
+      break;
+#endif
+
     default:
       return G_IO_ERROR_FAILED;
       break;
@@ -319,6 +325,7 @@ g_io_error_from_win32_error (gint error_code)
       return G_IO_ERROR_NOT_SUPPORTED;
 
     case WSAECONNRESET:
+    case WSAESHUTDOWN:
       return G_IO_ERROR_CONNECTION_CLOSED;
 
     case WSAEHOSTUNREACH:
@@ -337,6 +344,9 @@ g_io_error_from_win32_error (gint error_code)
     case ERROR_PIPE_LISTENING:
       return G_IO_ERROR_NOT_CONNECTED;
 
+    case WSAEMSGSIZE:
+      return G_IO_ERROR_MESSAGE_TOO_LARGE;
+
     default:
       return G_IO_ERROR_FAILED;
     }
