@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Simon McVittie <simon.mcvittie@collabora.co.uk>
  */
@@ -27,6 +25,7 @@
 #include <gio/gio.h>
 
 #include "test-io-stream.h"
+#include "test-pipe-unix.h"
 
 #ifdef G_OS_UNIX
 #   include <gio/gunixinputstream.h>
@@ -35,10 +34,10 @@
 #   error This module only exists on Unix
 #endif
 
-/*
+/**
  * test_pipe:
- * @is: (out) (allow-none): used to return a #GInputStream
- * @os: (out) (allow-none): used to return a #GOutputStream
+ * @is: (out) (optional): used to return a #GInputStream
+ * @os: (out) (optional): used to return a #GOutputStream
  * @error: used to raise an error
  *
  * Return a "pipe to self" connecting @is to @os. This can be used
@@ -64,7 +63,7 @@ test_pipe (GInputStream  **is,
       int e = errno;
 
       g_set_error (error, G_IO_ERROR, g_io_error_from_errno (e),
-                   g_strerror (e));
+                   "%s", g_strerror (e));
       return FALSE;
     }
 
@@ -81,10 +80,10 @@ test_pipe (GInputStream  **is,
   return TRUE;
 }
 
-/*
+/**
  * test_bidi_pipe:
- * @left: (out) (allow-none): used to return one #GIOStream
- * @right: (out) (allow-none): used to return the other #GIOStream
+ * @left: (out) (optional): used to return one #GIOStream
+ * @right: (out) (optional): used to return the other #GIOStream
  * @error: used to raise an error
  *
  * Return two #GIOStream<!---->s connected to each other with pipes.
@@ -105,7 +104,7 @@ test_bidi_pipe (GIOStream **left,
   GOutputStream *left_out = NULL;
   GInputStream *right_in = NULL;
   GOutputStream *right_out = NULL;
-  gboolean ret;
+  gboolean ret = FALSE;
 
   if (!test_pipe (&left_in, &right_out, error))
     goto out;
