@@ -51,7 +51,7 @@
 
 /* --- defines --- */
 #define PARAM_FLOATING_FLAG                     0x2
-#define	G_PARAM_USER_MASK			(~0 << G_PARAM_USER_SHIFT)
+#define	G_PARAM_USER_MASK			(~0U << G_PARAM_USER_SHIFT)
 #define PSPEC_APPLIES_TO_VALUE(pspec, value)	(G_TYPE_CHECK_VALUE_TYPE ((value), G_PARAM_SPEC_VALUE_TYPE (pspec)))
 
 /* --- prototypes --- */
@@ -81,6 +81,7 @@ static gchar*	value_param_lcopy_value		(const GValue	*value,
 typedef struct
 {
   GValue default_value;
+  GQuark name_quark;
 } GParamSpecPrivate;
 
 static gint g_param_private_offset;
@@ -416,7 +417,7 @@ is_canonical (const gchar *key)
  * @blurb, which should be a somewhat longer description, suitable for
  * e.g. a tooltip. The @nick and @blurb should ideally be localized.
  *
- * Returns: a newly allocated #GParamSpec instance
+ * Returns: (type GObject.ParamSpec): a newly allocated #GParamSpec instance
  */
 gpointer
 g_param_spec_internal (GType        param_type,
@@ -426,6 +427,7 @@ g_param_spec_internal (GType        param_type,
 		       GParamFlags  flags)
 {
   GParamSpec *pspec;
+  GParamSpecPrivate *priv;
   
   g_return_val_if_fail (G_TYPE_IS_PARAM (param_type) && param_type != G_TYPE_PARAM, NULL);
   g_return_val_if_fail (name != NULL, NULL);
@@ -454,6 +456,9 @@ g_param_spec_internal (GType        param_type,
         }
     }
 
+  priv = g_param_spec_get_private (pspec);
+  priv->name_quark = g_quark_from_string (pspec->name);
+
   if (flags & G_PARAM_STATIC_NICK)
     pspec->_nick = (gchar*) nick;
   else
@@ -579,14 +584,10 @@ g_param_spec_steal_qdata (GParamSpec *pspec,
 GParamSpec*
 g_param_spec_get_redirect_target (GParamSpec *pspec)
 {
-  g_return_val_if_fail (G_IS_PARAM_SPEC (pspec), NULL);
+  GTypeInstance *inst = (GTypeInstance *)pspec;
 
-  if (G_IS_PARAM_SPEC_OVERRIDE (pspec))
-    {
-      GParamSpecOverride *ospec = G_PARAM_SPEC_OVERRIDE (pspec);
-
-      return ospec->overridden;
-    }
+  if (inst && inst->g_class && inst->g_class->g_type == G_TYPE_PARAM_OVERRIDE)
+    return ((GParamSpecOverride*)pspec)->overridden;
   else
     return NULL;
 }
@@ -1429,7 +1430,7 @@ g_param_type_register_static (const gchar              *name,
 /**
  * g_value_set_param:
  * @value: a valid #GValue of type %G_TYPE_PARAM
- * @param: (allow-none): the #GParamSpec to be set
+ * @param: (nullable): the #GParamSpec to be set
  *
  * Set the contents of a %G_TYPE_PARAM #GValue to @param.
  */
@@ -1451,7 +1452,7 @@ g_value_set_param (GValue     *value,
 /**
  * g_value_set_param_take_ownership: (skip)
  * @value: a valid #GValue of type %G_TYPE_PARAM
- * @param: (allow-none): the #GParamSpec to be set
+ * @param: (nullable): the #GParamSpec to be set
  *
  * This is an internal function introduced mainly for C marshallers.
  *
@@ -1467,7 +1468,7 @@ g_value_set_param_take_ownership (GValue     *value,
 /**
  * g_value_take_param: (skip)
  * @value: a valid #GValue of type %G_TYPE_PARAM
- * @param: (allow-none): the #GParamSpec to be set
+ * @param: (nullable): the #GParamSpec to be set
  *
  * Sets the contents of a %G_TYPE_PARAM #GValue to @param and takes
  * over the ownership of the callers reference to @param; the caller
@@ -1524,11 +1525,11 @@ g_value_dup_param (const GValue *value)
 
 /**
  * g_param_spec_get_default_value:
- * @param: a #GParamSpec
+ * @pspec: a #GParamSpec
  *
- * Gets the default value of @param as a pointer to a #GValue.
+ * Gets the default value of @pspec as a pointer to a #GValue.
  *
- * The #GValue will remain value for the life of @param.
+ * The #GValue will remain value for the life of @pspec.
  *
  * Returns: a pointer to a #GValue which must not be modified
  *
@@ -1568,3 +1569,26 @@ g_param_spec_get_default_value (GParamSpec *pspec)
 
   return &priv->default_value;
 }
+
+/**
+ * g_param_spec_get_name_quark:
+ * @pspec: a #GParamSpec
+ *
+ * Gets the GQuark for the name.
+ *
+ * Returns: the GQuark for @pspec->name.
+ *
+ * Since: 2.46
+ */
+GQuark
+g_param_spec_get_name_quark (GParamSpec *pspec)
+{
+  GParamSpecPrivate *priv = g_param_spec_get_private (pspec);
+
+  /* Return the quark that we've stashed away at creation time.
+   * This lets us avoid a lock and a hash table lookup when
+   * dispatching property change notification.
+   */
+
+  return priv->name_quark;
+}
